==> vuurdraakbot-1.0.8-AG.zip: vuurdraakbot.py <==
#!/usr/bin/python
__module_name__ = "Vuurdraak Bot"
__module_version__ = "1.0.8" 
__module_description__ = "Vuurdraak Bot made by Rene Christians"

import os
import re
import string
import time
import xchat

print ("\0036" + __module_name__ + " " + __module_version__ + " has been loaded succesfully")

#the globals go here
vuurdraak = {}
Tank_Req_User = {}
tank_requested = {}
tank_request_Q = {}
option = {}
Number_of_tanks_requested = {}
Greatings_Viewer = {}
xchatdir = xchat.get_info("xchatdir")
invalid = re.compile('[A-Z]', re.I)
from random import randint

#the functions go here
def load_vars():
    global vuurdraak
    try:
        vuurdraak[0] = round(time.time() )
        vuurdraak[1] = round(time.time() )
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global Tank_Req_User
    try:
        Tank_Req_User[0] = "Nobody"
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global tank_requested
    try:
        tank_requested[Tank_Req_User[0]] = "No Tank"
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global tank_request_Q
    try:
        tank_request_Q[0] = "No Tank"
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global Number_of_tanks_requested
    try:
        Number_of_tanks_requested[0] = 0
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global Greatings_Viewer
    try:
        Greatings_Viewer["streamelements"] = "X"
    except EnvironmentError:
        print ("\0034", "Error loading script")


    global option
    try:
        inifile = open(os.path.join(xchatdir,"vuurdraak.ini"), 'rU')
        option["anti_spam_speed"] = "2"
        option["font_size_text"] = "7"
        option["great_viewers"] = "yes"
        option["set_mod1"] = "assassn_gallic316"
        option["set_mod2"] = ""
        option["set_mod3"] = ""
        option["set_mod4"] = ""
        option["set_mod5"] = ""
        line = inifile.readline() #The first line is a comment
        line = inifile.readline()
        if line == '\n' or line == '\r' or line == "" :
            line = inifile.readline()
        line.strip('\n')
        line.strip('\r')
        while line != "":
            if "[End of INI]" in line:
                print ("\00311" + "Vuurdraak Bot's vuurdraak.ini loaded successfully")
                print ("\00313" + "Anti spam speed is set to one command per " + str.strip(option["anti_spam_speed"]) + " seconds")
                inifile.close
                return xchat.EAT_NONE
            par1, par2 = re.split("=", line)
            par1 = par1.lower()
            option[par1] = str(par2).strip('\n')
            option[par1] = option[par1].strip('\r')
            line = inifile.readline()
            if line == '\n' or line == '\r' or line == "":
                line = inifile.readline()
                if "[End of INI]" in line:
                    print ("\00311" + "Vuurdraak Bot's vuurdraak.ini loaded successfully")
                    print ("\00313" + "Anti spam speed is set to one command per " + str.strip(option["anti_spam_speed"]) + " seconds")
                    inifile.close
                    return xchat.EAT_NONE
            line.strip('\n')
            line.strip('\r')
        inifile.close

        print ("\00311" + "No [End of INI] found, but Vuurdraak Bot's vuurdraak.ini loaded successfully")
        print ("\00313" + "Anti spam speed is set to one command per " + str.strip(option["anti_spam_speed"]) + " seconds")

    except EnvironmentError:
        print ("\0034", "Could not open vuurdraak.ini  put it in your "+xchatdir+"")

def on_text(word, word_eol, userdata):
    destination = xchat.get_context()    
    trigger = re.split(' ',word[1])
    vuurdraak[0] = round(time.time() ) - int(option["anti_spam_speed"])

    if option["great_viewers"] == "yes":
       try:
          Greatings_Viewer[word[0]]
       except:
          Greatings_Viewer[word[0]] = "X"
          variable = randint(0,9)
          if variable == 0:
             destination.command("say Welcome " + word[0] + " HeyGuys")
          if variable == 1:
             destination.command("say Welcome " + word[0] + " KonCha")
          if variable == 2:
             destination.command("say Nice to see you " + word[0] + " BloodTrail")
          if variable == 3:
             destination.command("say Welcome " + word[0] + " VoHiYo ")
          if variable == 4:
             destination.command("say Nice to see you " + word[0] + " KonCha")
          if variable == 5:
             destination.command("say Nice to see you " + word[0] + " HeyGuys")
          if variable == 6:
             destination.command("say HeyGuys " + word[0] + "")
          if variable == 7:
             destination.command("say KonCha " + word[0] + "")
          if variable == 8:
             destination.command("say VoHiYo " + word[0] + "")
          if variable == 9:
             destination.command("say Welcome " + word[0] + " BloodTrail")
       

    if trigger[0] == '!redeem':
       if trigger[1] == 'tank' or trigger[1] == 'sr':
          Tank_Req_User[0] = word[0]
          tank_requested[Tank_Req_User[0]] = trigger[2]

          try:
             trigger[3]
          except:
             # trigger[3] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[3]

          try:
             trigger[4]
          except:
             # trigger[4] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[4]

          try:
             trigger[5]
          except:
             # trigger[5] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[5]

          try:
             trigger[6]
          except:
             # trigger[6] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[6]

          try:
             trigger[7]
          except:
             # trigger[7] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[7]

          try:
             trigger[8]
          except:
             # trigger[8] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[8]

          try:
             trigger[9]
          except:
             # trigger[9] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[9]


    if word[0] == 'streamelements':
       try:
          trigger[10] 
       except:
          # trigger[10] not defined
          return xchat.EAT_NONE
       else:
          word_check = "" + trigger[1] + trigger[2] + trigger[3] + trigger[4] + trigger[5] + trigger[6] + trigger[7] + ""
          word_check2 = "" + trigger[1] + trigger[2] + trigger[3] + "" 
          print(word_check)
          if word_check == "yousuccessfullyredeemedrequestatankfor":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Tank_Req_User[2] = Tank_Req_User[3].lower()
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> " + tank_requested[Tank_Req_User[2]] + ""
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

          if word_check == "yousuccessfullyredeemedChurchillguncarriergame":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> Churchill Gun Carrier"
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

          if word_check == "yousuccessfullyredeemedHEOnlygamein":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> High Explosives Only"
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

          if word_check == "yousuccessfullyredeemedSupertankrequest":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Tank_Req_User[2] = Tank_Req_User[3].lower()
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -SUPER-Request-> " + tank_requested[Tank_Req_User[2]] + ""
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

##          if word_check2 == "yousuccessfullyredeemed" and trigger[4] != "-":
##              ## Request Succesfull
##              Tank_Req_User[1] = trigger[0].strip( '@' )
##              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
##              Number_of_tanks_requested[0] += 1
##              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> " + trigger[4] + ""
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE



    ## REMOVE AFTER TESTING !!!!
    ##if word[0] == 'vuurdraak_':
    ##    if trigger[0] == "!testreq":
    ##        ## Request Succesfull
    ##        Tank_Req_User[1] = trigger[0].strip( '@' )
    ##        Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
    ##        Tank_Req_User[2] = Tank_Req_User[3].lower()
    ##        Number_of_tanks_requested[0] += 1
    ##        tank_request_Q[Number_of_tanks_requested[0]] = "" + "Vuurdraak_" + " -requested-> " + trigger[1] + ""
    ##        destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp    -> " + str(Number_of_tanks_requested[0]) + "" )
    ##        write_tank_req()



    if trigger[0] == '!rdone':
          if word[0] == option["set_mod1"] or word[0] == option["set_mod2"] or word[0] == option["set_mod3"] or word[0] == option["set_mod4"] or word[0] == option["set_mod5"]:
            try:
               trigger[1]
            except:
               List_line = 1
            else:
               List_line = int(trigger[1])
               if List_line < 0:
                  List_line = 0
            if Number_of_tanks_requested[0] > 0:
                 ## purge list
                 Nr_Of_Tanks = List_line
                 while Number_of_tanks_requested[0] > Nr_Of_Tanks:
                     try:
                        tank_request_Q[Nr_Of_Tanks + 1] 
                     except:
                        Nr_Of_Tanks = Nr_Of_Tanks
                     else:
                        tank_request_Q[Nr_Of_Tanks] = tank_request_Q[Nr_Of_Tanks + 1]   
                     Nr_Of_Tanks += 1
                 Number_of_tanks_requested[0] -= 1
                 write_tank_req()


    if vuurdraak[0] <= vuurdraak[1]:
        return xchat.EAT_NONE
    vuurdraak[1] = round(time.time() )

    word[1] = word[1].lower()
    try:
      if option[word[1]] != '':
          destination.command("say " + option[word[1]])

    except:
      if trigger[0] == '!calc':
          calculate(string.join(trigger[1]), destination)

    return xchat.EAT_NONE

def write_tank_req():
    try:
        Nr_Of_Tanks = Number_of_tanks_requested[0]
        if Number_of_tanks_requested[0] > 0:
              tankfile = open(os.path.join(xchatdir,"tankreq.txt"), 'w')
              HTMLtankfile = open(os.path.join(xchatdir,"tankreq.html"), 'w')
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write('<HTML><HEAD><meta http-equiv="refresh" content="1"></HEAD><BODY><H1><font size="' + option["font_size_text"] + '"> \n \r')
              Nr_Of_Tanks_Rev = 1
              while Nr_Of_Tanks > 0:
                  tankfile.write(tank_request_Q[Nr_Of_Tanks_Rev] + "\n \r") 
                  HTMLtankfile.write("" + tank_request_Q[Nr_Of_Tanks_Rev] + "<br> \n \r") 
                  Nr_Of_Tanks -= 1
                  Nr_Of_Tanks_Rev += 1
              tankfile.close() 
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write("</H1></BODY></HTML> \n \r")
              HTMLtankfile.close() 
        else:
              tankfile = open(os.path.join(xchatdir,"tankreq.txt"), 'w')
              HTMLtankfile = open(os.path.join(xchatdir,"tankreq.html"), 'w')
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write('<HTML><HEAD><meta http-equiv="refresh" content="1"></HEAD><BODY><H1><font size="' + option["font_size_text"] + '"> \n \r')
              tankfile.write(" \n \r") 
              HTMLtankfile.write(" \n \r") 
              tankfile.close() 
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write("</H1></BODY></HTML> \n \r")
              HTMLtankfile.close()  

    except:
        return xchat.EAT_NONE


    return xchat.EAT_NONE
  
def calculate(expression, destination):
    try:
      if not invalid.search(expression):
        expression2 = re.sub('[A-Za-z]', '', expression)
        answer = eval(expression2)
        destination.command("say " + expression + " =" +
          " " + str(answer))
    
    except:
        return xchat.EAT_NONE


    return xchat.EAT_NONE
   
    
load_vars()
write_tank_req()

#The hooks go here
xchat.hook_print('Channel Message', on_text)

#LICENSE GPL
#Last modified 8-25-06 by Cancel
#Last modified 3-09-16 by Vuurdraak
#This was my first Python script, I based Vuurdraak Bot on Cancel's CalcBot and preserved it's !calc functionality.

==> vuurdraakbot-1.1.1-AG.zip: vuurdraakbot.py <==
#!/usr/bin/python
__module_name__ = "Vuurdraak Bot"
__module_version__ = "1.1.1" 
__module_description__ = "Vuurdraak Bot made by Rene Christians"

import os
import re
import string
import time
import xchat

print ("\0036" + __module_name__ + " " + __module_version__ + " has been loaded succesfully")

#the globals go here
vuurdraak = {}
Tank_Req_User = {}
tank_requested = {}
tank_request_Q = {}
option = {}
Number_of_tanks_requested = {}
Greatings_Viewer = {}
xchatdir = xchat.get_info("xchatdir")
invalid = re.compile('[A-Z]', re.I)
from random import randint

#the functions go here
def load_vars():
    global vuurdraak
    try:
        vuurdraak[0] = round(time.time() )
        vuurdraak[1] = round(time.time() )
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global Tank_Req_User
    try:
        Tank_Req_User[0] = "Nobody"
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global tank_requested
    try:
        tank_requested[Tank_Req_User[0]] = "No Tank"
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global tank_request_Q
    try:
        tank_request_Q[0] = "No Tank"
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global Number_of_tanks_requested
    try:
        Number_of_tanks_requested[0] = 0
    except EnvironmentError:
        print ("\0034", "Error loading script")

    global Greatings_Viewer
    try:
        Greatings_Viewer["streamelements"] = "X"
    except EnvironmentError:
        print ("\0034", "Error loading script")


    global option
    try:
        inifile = open(os.path.join(xchatdir,"vuurdraak.ini"), 'rU')
        option["anti_spam_speed"] = "2"
        option["font_size_text"] = "7"
        option["great_viewers"] = "yes"
        option["set_mod1"] = "assassn_gallic316"
        option["set_mod2"] = ""
        option["set_mod3"] = ""
        option["set_mod4"] = ""
        option["set_mod5"] = ""
        line = inifile.readline() #The first line is a comment
        line = inifile.readline()
        if line == '\n' or line == '\r' or line == "" :
            line = inifile.readline()
        line.strip('\n')
        line.strip('\r')
        while line != "":
            if "[End of INI]" in line:
                print ("\00311" + "Vuurdraak Bot's vuurdraak.ini loaded successfully")
                print ("\00313" + "Anti spam speed is set to one command per " + str.strip(option["anti_spam_speed"]) + " seconds")
                inifile.close
                return xchat.EAT_NONE
            par1, par2 = re.split("=", line)
            par1 = par1.lower()
            option[par1] = str(par2).strip('\n')
            option[par1] = option[par1].strip('\r')
            line = inifile.readline()
            if line == '\n' or line == '\r' or line == "":
                line = inifile.readline()
                if "[End of INI]" in line:
                    print ("\00311" + "Vuurdraak Bot's vuurdraak.ini loaded successfully")
                    print ("\00313" + "Anti spam speed is set to one command per " + str.strip(option["anti_spam_speed"]) + " seconds")
                    inifile.close
                    return xchat.EAT_NONE
            line.strip('\n')
            line.strip('\r')
        inifile.close

        print ("\00311" + "No [End of INI] found, but Vuurdraak Bot's vuurdraak.ini loaded successfully")
        print ("\00313" + "Anti spam speed is set to one command per " + str.strip(option["anti_spam_speed"]) + " seconds")

    except EnvironmentError:
        print ("\0034", "Could not open vuurdraak.ini  put it in your "+xchatdir+"")

def on_text(word, word_eol, userdata):
    destination = xchat.get_context()    
    trigger = re.split(' ',word[1])
    vuurdraak[0] = round(time.time() ) - int(option["anti_spam_speed"])

    if option["great_viewers"] == "yes":
       try:
          Greatings_Viewer[word[0]]
       except:
          Greatings_Viewer[word[0]] = "X"
          variable = randint(0,9)
          if variable == 0:
             destination.command("say Welcome " + word[0] + " HeyGuys")
          if variable == 1:
             destination.command("say Welcome " + word[0] + " KonCha")
          if variable == 2:
             destination.command("say Nice to see you " + word[0] + " BloodTrail")
          if variable == 3:
             destination.command("say Welcome " + word[0] + " VoHiYo ")
          if variable == 4:
             destination.command("say Nice to see you " + word[0] + " KonCha")
          if variable == 5:
             destination.command("say Nice to see you " + word[0] + " HeyGuys")
          if variable == 6:
             destination.command("say HeyGuys " + word[0] + "")
          if variable == 7:
             destination.command("say KonCha " + word[0] + "")
          if variable == 8:
             destination.command("say VoHiYo " + word[0] + "")
          if variable == 9:
             destination.command("say Welcome " + word[0] + " BloodTrail")
       

    if trigger[0] == '!redeem':
       if trigger[1] == 'tank' or trigger[1] == 'sr':
          Tank_Req_User[0] = word[0]
          tank_requested[Tank_Req_User[0]] = trigger[2]

          try:
             trigger[3]
          except:
             # trigger[3] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[3]

          try:
             trigger[4]
          except:
             # trigger[4] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[4]

          try:
             trigger[5]
          except:
             # trigger[5] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[5]

          try:
             trigger[6]
          except:
             # trigger[6] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[6]

          try:
             trigger[7]
          except:
             # trigger[7] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[7]

          try:
             trigger[8]
          except:
             # trigger[8] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[8]

          try:
             trigger[9]
          except:
             # trigger[9] not defined
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]]
          else:
             tank_requested[Tank_Req_User[0]] = tank_requested[Tank_Req_User[0]] + " " + trigger[9]


    if word[0] == 'streamelements':
       try:
          trigger[10] 
       except:
          # trigger[10] not defined
          return xchat.EAT_NONE
       else:
          word_check = "" + trigger[1] + trigger[2] + trigger[3] + trigger[4] + trigger[5] + trigger[6] + trigger[7] + ""
          word_check2 = "" + trigger[1] + trigger[2] + trigger[3] + "" 
          print(word_check)
          if word_check == "yousuccessfullyredeemedrequestatankfor":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Tank_Req_User[2] = Tank_Req_User[3].lower()
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> " + tank_requested[Tank_Req_User[2]] + ""
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

          if word_check == "yousuccessfullyredeemedChurchillguncarriergame":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> Churchill Gun Carrier"
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

          if word_check == "yousuccessfullyredeemedHEOnlygamein":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> High Explosives Only"
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

          if word_check == "yousuccessfullyredeemedSupertankrequest":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Tank_Req_User[2] = Tank_Req_User[3].lower()
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -SUPER-Request-> " + tank_requested[Tank_Req_User[2]] + ""
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE

          if word_check2 == "yousuccessfullyredeemed" and trigger[4] != "-":
              ## Request Succesfull
              Tank_Req_User[1] = trigger[0].strip( '@' )
              Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
              Number_of_tanks_requested[0] += 1
              tank_request_Q[Number_of_tanks_requested[0]] = "" + Tank_Req_User[3] + " -requested-> " + trigger[4] + ""
              # destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp")
              write_tank_req()
              return xchat.EAT_NONE



    ## REMOVE AFTER TESTING !!!!
    ##if word[0] == 'vuurdraak_':
    ##    if trigger[0] == "!testreq":
    ##        ## Request Succesfull
    ##        Tank_Req_User[1] = trigger[0].strip( '@' )
    ##        Tank_Req_User[3] = Tank_Req_User[1].strip( ',' )
    ##        Tank_Req_User[2] = Tank_Req_User[3].lower()
    ##        Number_of_tanks_requested[0] += 1
    ##        tank_request_Q[Number_of_tanks_requested[0]] = "" + "Vuurdraak_" + " -requested-> " + trigger[1] + ""
    ##        destination.command("say /me " + tank_request_Q[Number_of_tanks_requested[0]] + " PogChamp    -> " + str(Number_of_tanks_requested[0]) + "" )
    ##        write_tank_req()



    if trigger[0] == '!rdone':
          if word[0] == option["set_mod1"] or word[0] == option["set_mod2"] or word[0] == option["set_mod3"] or word[0] == option["set_mod4"] or word[0] == option["set_mod5"]:
            try:
               trigger[1]
            except:
               List_line = 1
            else:
               List_line = int(trigger[1])
               if List_line < 0:
                  List_line = 0
            if Number_of_tanks_requested[0] > 0:
                 ## purge list
                 Nr_Of_Tanks = List_line
                 while Number_of_tanks_requested[0] > Nr_Of_Tanks:
                     try:
                        tank_request_Q[Nr_Of_Tanks + 1] 
                     except:
                        Nr_Of_Tanks = Nr_Of_Tanks
                     else:
                        tank_request_Q[Nr_Of_Tanks] = tank_request_Q[Nr_Of_Tanks + 1]   
                     Nr_Of_Tanks += 1
                 Number_of_tanks_requested[0] -= 1
                 write_tank_req()


    if vuurdraak[0] <= vuurdraak[1]:
        return xchat.EAT_NONE
    vuurdraak[1] = round(time.time() )

    word[1] = word[1].lower()
    try:
      if option[word[1]] != '':
          destination.command("say " + option[word[1]])

    except:
      if trigger[0] == '!calc':
          calculate(string.join(trigger[1]), destination)

    return xchat.EAT_NONE

def write_tank_req():
    try:
        Nr_Of_Tanks = Number_of_tanks_requested[0]
        if Number_of_tanks_requested[0] > 0:
              tankfile = open(os.path.join(xchatdir,"tankreq.txt"), 'w')
              HTMLtankfile = open(os.path.join(xchatdir,"tankreq.html"), 'w')
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write('<HTML><HEAD><meta http-equiv="refresh" content="1"></HEAD><BODY><H1><font size="' + option["font_size_text"] + '"> \n \r')
              Nr_Of_Tanks_Rev = 1
              while Nr_Of_Tanks > 0:
                  tankfile.write(tank_request_Q[Nr_Of_Tanks_Rev] + "\n \r") 
                  HTMLtankfile.write("" + tank_request_Q[Nr_Of_Tanks_Rev] + "<br> \n \r") 
                  Nr_Of_Tanks -= 1
                  Nr_Of_Tanks_Rev += 1
              tankfile.close() 
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write("</H1></BODY></HTML> \n \r")
              HTMLtankfile.close() 
        else:
              tankfile = open(os.path.join(xchatdir,"tankreq.txt"), 'w')
              HTMLtankfile = open(os.path.join(xchatdir,"tankreq.html"), 'w')
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write('<HTML><HEAD><meta http-equiv="refresh" content="1"></HEAD><BODY><H1><font size="' + option["font_size_text"] + '"> \n \r')
              tankfile.write(" \n \r") 
              HTMLtankfile.write(" \n \r") 
              tankfile.close() 
              ## Ad extra HTML crap for writing to the file here
              HTMLtankfile.write("</H1></BODY></HTML> \n \r")
              HTMLtankfile.close()  

    except:
        return xchat.EAT_NONE


    return xchat.EAT_NONE
  
def calculate(expression, destination):
    try:
      if not invalid.search(expression):
        expression2 = re.sub('[A-Za-z]', '', expression)
        answer = eval(expression2)
        destination.command("say " + expression + " =" +
          " " + str(answer))
    
    except:
        return xchat.EAT_NONE


    return xchat.EAT_NONE
   
    
load_vars()
write_tank_req()

#The hooks go here
xchat.hook_print('Channel Message', on_text)

#LICENSE GPL
#Last modified 8-25-06 by Cancel
#Last modified 3-09-16 by Vuurdraak
#This was my first Python script, I based Vuurdraak Bot on Cancel's CalcBot and preserved it's !calc functionality.
